summaryrefslogtreecommitdiff
path: root/Source/IFFError.S
diff options
context:
space:
mode:
Diffstat (limited to 'Source/IFFError.S')
-rw-r--r--Source/IFFError.S88
1 files changed, 32 insertions, 56 deletions
diff --git a/Source/IFFError.S b/Source/IFFError.S
index 3472f59..28936a0 100644
--- a/Source/IFFError.S
+++ b/Source/IFFError.S
@@ -1,13 +1,13 @@
**
-** $Id: $
-** $Revision: $
+** $Id: IFFError.S,v 1.1 92/05/12 22:26:38 chris Exp $
+** $Revision: 1.1 $
**
** $Filename: IFFError.S $
-** $Author: Christian A. Weber $
+** $Author: chris $
** $Release: 19.1 $
-** $Date: 92/05/11 21:11:27 $
+** $Date: 92/05/12 22:26:38 $
**
-** iff.library/IFFLib_IFFError
+** iff.library/IFFL_IFFError
**
** COPYRIGHT (C) 1987-1992 BY CHRISTIAN A. WEBER, BRUGGERWEG 2,
** CH-8037 ZUERICH, SWITZERLAND. ALL RIGHTS RESERVED. NO PART
@@ -17,7 +17,7 @@
**
- IDNT IFFLib_IFFError
+ IDNT IFFL_IFFError
SECTION text,CODE
INCLUDE "IFFLib.i"
@@ -26,20 +26,20 @@
XDEF IFFErrorFunc
-******* iff.library/IFFLib_IFFError *****************************************
+******* iff.library/IFFL_IFFError *******************************************
*
* NAME
* IFFLib_IFFError -- Get detailed error descrpition
*
* SYNOPSIS
-* error = IFFLib_IFFError()
+* error = IFFL_IFFError()
* D0
*
-* LONG IFFLib_IFFError( void )
+* LONG IFFL_IFFError( VOID )
*
* FUNCTION
* If one of the above functions returns zero, you can call
* IFFLib_IFFError() to know the reason for the failure. An error
* code is returned, please refer to the files 'iff.h' or 'iff.i'
* for the complete list of errors.
*
@@ -48,32 +48,7 @@
*
* RESULT
* Error-number generated by the latest function call, or zero if
-* no error
-*
-* Cuurently the following numbers are used:
-*
-* Nr. Symbol Function Description
-*
-* 16 IFF_CANTOPENFILE OpenIFF() File not found
-* 17 IFF_READERROR OpenIFF() Read() returned an error
-* 18 IFF_NOMEM OpenIFF() Not enough memory for the file
-* 19 IFF_NOTIFF OpenIFF() File is not IFF
-* 20 IFF_WRITEERROR SaveBitMap() Cannot write the file
-*
-* 24 IFF_NOILBM DecodePic() IFF file is not an ILBM file
-* 25 IFF_NOBMHD DecodePic() BMHD chunk not found
-* 26 IFF_NOBODY DecodePic() BODY chunk not found
-* 27 IFF_TOOMANYPLANES DecodePic() Picture has more planes than the
-* BitMap (OBSOLETE SINCE 18.7!)
-* 28 IFF_UNKNOWNCOMPRESSION " Unknown compression type
-* 29 IFF_NOANHD ModifyFrame() ANHD chunk not found
-* 30 IFF_NODLTA ModifyFrame() DLTA chunk not found
-*
-* -1 IFF_BADTASK A task which did not open the IFF library
-* tried to call IFFError(). Since the IFF
-* library is capable of multi-tasking, the
-* error-values are stored for each task
-* separately.
+* no error.
*
* BUGS
* If you don't close the IFF library at the end of your program
@@ -82,19 +57,20 @@
* (This is not a bug, it's a feature ;-))
*
* SEE ALSO
+* <iff.h>
*
*****************************************************************************
*** Unseren Node nach D0 und A0 bringen, Set Z-Flag if not found
-FindOurNode: movea.l ib_SysBase(a5),a6
+FindOurNode: movea.l iffb_SysBase(a5),a6
move.l ThisTask(a6),d1
- move.l ib_ErrList(a5),d0 ; 1. Node in Error Liste
+ move.l iffb_ErrList(a5),d0 ; 1. Node in Error Liste
.findloop: movea.l d0,a0 ; next node
move.l LN_SUCC(a0),d0
beq.s .findend ; ---> Ende (Z-Flag gesetzt)
- cmp.l er_Task(a0),d1 ; Unser Node ?
+ cmp.l ifferr_Task(a0),d1 ; Unser Node ?
bne.s .findloop
move.l a0,d0 ; unser Node, Clear Z-Flag
.findend: rts
@@ -102,39 +78,39 @@ FindOurNode: movea.l ib_SysBase(a5),a6
*****************************************************************************
-ClearError: bsr FindOurNode ; Node nach D0 und A0
+ClearError: bsr FindOurNode ; Node nach D0 und A0
;; tst.l d0
- beq.s 1$ ; no node ---> nichts eintragen
- clr.l er_Error(a0)
-1$: moveq #1,d0 ; Code für 'OK'
+ beq.s 1$ ; no node ---> nichts eintragen
+ clr.l ifferr_Error(a0)
+1$: moveq #1,d0 ; Code für 'OK'
rts
*****************************************************************************
-SetError: move.l d0,-(SP) ; Error-Nummer retten
- bsr FindOurNode ; Node nach D0 und A0
+SetError: move.l d0,-(SP) ; Error-Nummer retten
+ bsr FindOurNode ; Node nach D0 und A0
;; tst.l d0
- beq.s 1$ ; no node ---> nichts eintragen
- move.l (SP),er_Error(a0)
+ beq.s 1$ ; kein Node ---> nichts eintragen
+ move.l (SP),ifferr_Error(a0)
1$:
addq.l #4,SP
- moveq #0,d0 ; Code für 'Error'
+ moveq #0,d0 ; Code für 'Error'
rts
*****************************************************************************
IFFErrorFunc: movem.l a5-a6,-(SP)
- movea.l a6,a5 ; IFFBase
- bsr FindOurNode ; Node nach D0 und A0
+ movea.l a6,a5 ; IFFBase
+ bsr FindOurNode ; Node nach D0 und A0
;; tst.l d0
- beq.s 1$ ; kein Node ---> Fehler!!
- move.l er_Error(a0),d0
- clr.l er_Error(a0) ; Error rücksetzen
+ beq.s 1$ ; kein Node ---> Fehler!!
+ move.l ifferr_Error(a0),d0
+ clr.l ifferr_Error(a0) ; Error rücksetzen
2$: movem.l (SP)+,a5-a6
rts
1$:
- moveq #IFF_BADTASK,d0
+ moveq #IFFL_ERROR_BADTASK,d0
bra.s 2$
END
@@ -26,20 +26,20 @@
*
* NAME
-* IFFLib_IFFError -- Get detailed error descrpition
+* IFFL_IFFError -- Get detailed error descrpition after an error
*
* SYNOPSIS
@@ -26,20 +26,20 @@
*
* FUNCTION
-* If one of the above functions returns zero, you can call
-* IFFLib_IFFError() to know the reason for the failure. An error
+* If one of the iff.library functions returns zero, you can call
+* IFFL_IFFError() to know the reason for the failure. An error
* code is returned, please refer to the files 'iff.h' or 'iff.i'
* for the complete list of errors.